@@ -211,7 +211,7 @@ class AqlQueryTestCase(ExtendedTestCase):
         doc = docs[0]
         self.assertDocumentsEqual(doc, self.col1_doc2)
 
-    def test_filter_from_multiple_collections(self):
+    def test_filter_of_multiple_collections(self):
         q = Query()
         q.append_collection(self.test_1_col.name)
         q.append_collection(self.test_2_col.name)
@@ -294,6 +294,46 @@ class AqlQueryTestCase(ExtendedTestCase):
 
         self.assertDocumentsEqual(doc1, self.col1_doc3)
 
+    def test_greater_filtering(self):
+        q = Query()
+        q.append_collection(self.test_1_col.name)
+        q.filter(little_number__gt=20)
+
+        docs = q.execute()
+
+        self.assertEqual(len(docs), 1)
+
+        self.assertDocumentsEqual(self.col1_doc1, docs[0])
+
+    def test_greater_equals_filtering(self):
+        q = Query()
+        q.append_collection(self.test_1_col.name)
+        q.filter(little_number__gte=3)
+
+        docs = q.execute()
+
+        self.assertEqual(len(docs), 2)
+
+    def test_lower_filtering(self):
+        q = Query()
+        q.append_collection(self.test_1_col.name)
+        q.filter(little_number__lt=3)
+
+        docs = q.execute()
+
+        self.assertEqual(len(docs), 1)
+
+        self.assertDocumentsEqual(self.col1_doc2, docs[0])
+
+    def test_lower_equals_filtering(self):
+        q = Query()
+        q.append_collection(self.test_1_col.name)
+        q.filter(little_number__lte=3)
+
+        docs = q.execute()
+
+        self.assertEqual(len(docs), 2)
+
 
 class SimpleQueryTestCase(ExtendedTestCase):
     def setUp(self):
